==> bokeh-2.2.0.dev4.tar.gz: bokeh-2.2.0.dev4/bokeh/_testing/plugins/managed_server_loop.py <==
#-----------------------------------------------------------------------------
# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
# All rights reserved.
#
# The full license is in the file LICENSE.txt, distributed with this software.
#-----------------------------------------------------------------------------
''' Define a Pytest plugin to provide a Bokeh server

'''

#-----------------------------------------------------------------------------
# Boilerplate
#-----------------------------------------------------------------------------
import logging # isort:skip
log = logging.getLogger(__name__)

#-----------------------------------------------------------------------------
# Imports
#-----------------------------------------------------------------------------

# Standard library imports
from contextlib import contextmanager

# External imports
import pytest

# Bokeh imports
from bokeh.server.server import Server

#-----------------------------------------------------------------------------
# Globals and constants
#-----------------------------------------------------------------------------

pytest_plugins = ()

__all__ = (
    'ManagedServerLoop',
)

#-----------------------------------------------------------------------------
# General API
#-----------------------------------------------------------------------------

@pytest.fixture
def ManagedServerLoop(unused_tcp_port):
    @contextmanager
    def msl(application, port=None, **server_kwargs):
        if port is None:
            port = unused_tcp_port
        server = Server(application, port=port, **server_kwargs)
        try:
            server.start()
            yield server
        finally:
            server.unlisten()
            server.stop()
    return msl


#-----------------------------------------------------------------------------
# Dev API
#-----------------------------------------------------------------------------

#-----------------------------------------------------------------------------
# Private API
#-----------------------------------------------------------------------------

#-----------------------------------------------------------------------------
# Code
#-----------------------------------------------------------------------------

==> bokeh-2.4.0.dev2.tar.gz: bokeh-2.4.0.dev2/bokeh/_testing/plugins/managed_server_loop.py <==
#-----------------------------------------------------------------------------
# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
# All rights reserved.
#
# The full license is in the file LICENSE.txt, distributed with this software.
#-----------------------------------------------------------------------------
''' Define a Pytest plugin to provide a Bokeh server

'''

#-----------------------------------------------------------------------------
# Boilerplate
#-----------------------------------------------------------------------------
from __future__ import annotations

import logging # isort:skip
log = logging.getLogger(__name__)

#-----------------------------------------------------------------------------
# Imports
#-----------------------------------------------------------------------------

# Standard library imports
from contextlib import contextmanager
from typing import (
    TYPE_CHECKING,
    Any,
    ContextManager,
    Iterator,
)

# External imports
import pytest
from typing_extensions import Protocol

# Bokeh imports
from bokeh.server.server import Server

if TYPE_CHECKING:
    from bokeh.application import Application

#-----------------------------------------------------------------------------
# Globals and constants
#-----------------------------------------------------------------------------

pytest_plugins = ()

__all__ = (
    'ManagedServerLoop',
)

#-----------------------------------------------------------------------------
# General API
#-----------------------------------------------------------------------------

class MSL(Protocol):
    def __call__(self, application: Application, port: int | None = None, **server_kwargs: Any) -> ContextManager[Server]: ...

@pytest.fixture
def ManagedServerLoop(unused_tcp_port: int) -> MSL:
    @contextmanager
    def msl(application: Application, port: int | None = None, **server_kwargs: Any) -> Iterator[Server]:
        if port is None:
            port = unused_tcp_port
        server = Server(application, port=port, **server_kwargs)
        try:
            server.start()
            yield server
        finally:
            server.unlisten()
            server.stop()
    return msl

#-----------------------------------------------------------------------------
# Dev API
#-----------------------------------------------------------------------------

#-----------------------------------------------------------------------------
# Private API
#-----------------------------------------------------------------------------

#-----------------------------------------------------------------------------
# Code
#-----------------------------------------------------------------------------
